pub struct PermissionMetadataSet {
entries: Vec<PermissionMetadataEntry>,
sources: Vec<PermissionResolutionSource>,
}Expand description
A flat effective permission metadata set.
Fields
entries: Vec<PermissionMetadataEntry>sources: Vec<PermissionResolutionSource>Implementations
Sourceimpl PermissionMetadataSet
impl PermissionMetadataSet
Sourcepub fn from_entries(
entries: impl IntoIterator<Item = PermissionMetadataEntry>,
) -> Self
pub fn from_entries( entries: impl IntoIterator<Item = PermissionMetadataEntry>, ) -> Self
Creates a subject metadata set from entries.
Sourcepub fn entries(&self) -> &[PermissionMetadataEntry]
pub fn entries(&self) -> &[PermissionMetadataEntry]
Returns all entries in insertion order.
Sourcepub fn push(&mut self, entry: PermissionMetadataEntry)
pub fn push(&mut self, entry: PermissionMetadataEntry)
Adds one subject metadata rule.
Sourcepub fn set(&mut self, key: Identifier, value: PermissionMetadataValue)
pub fn set(&mut self, key: Identifier, value: PermissionMetadataValue)
Sets one exact global value, replacing any previous exact value.
Sourcepub fn set_in(
&mut self,
key: Identifier,
context: PermissionRuleContext,
value: PermissionMetadataValue,
)
pub fn set_in( &mut self, key: Identifier, context: PermissionRuleContext, value: PermissionMetadataValue, )
Sets one exact contextual value, replacing any previous exact value.
Sourcepub fn unset(&mut self, key: &Identifier) -> bool
pub fn unset(&mut self, key: &Identifier) -> bool
Removes one exact global value.
Sourcepub fn unset_in(
&mut self,
key: &Identifier,
context: &PermissionRuleContext,
) -> bool
pub fn unset_in( &mut self, key: &Identifier, context: &PermissionRuleContext, ) -> bool
Removes one exact contextual value.
Sourcepub fn resolve(&self, key: &Identifier) -> Option<&PermissionMetadataValue>
pub fn resolve(&self, key: &Identifier) -> Option<&PermissionMetadataValue>
Resolves one value in the global context.
Sourcepub fn resolve_in(
&self,
key: &Identifier,
context: &PermissionContext,
) -> Option<&PermissionMetadataValue>
pub fn resolve_in( &self, key: &Identifier, context: &PermissionContext, ) -> Option<&PermissionMetadataValue>
Resolves one value in an active permission context.
More-specific contexts win. Ties prefer subject metadata, then group priority, then the final insertion order for deterministic resolution.
Sourcepub fn resolve_detailed(
&self,
key: &Identifier,
) -> Option<PermissionMetadataResolution>
pub fn resolve_detailed( &self, key: &Identifier, ) -> Option<PermissionMetadataResolution>
Resolves one global value and returns the winning rule.
Sourcepub fn resolve_in_detailed(
&self,
key: &Identifier,
context: &PermissionContext,
) -> Option<PermissionMetadataResolution>
pub fn resolve_in_detailed( &self, key: &Identifier, context: &PermissionContext, ) -> Option<PermissionMetadataResolution>
Resolves one contextual value and returns the winning rule.
pub(super) fn push_group( &mut self, entry: PermissionMetadataEntry, group: &str, group_priority: i32, )
fn push_with_source( &mut self, entry: PermissionMetadataEntry, source: PermissionResolutionSource, )
fn retain_entries(&mut self, keep: impl FnMut(&PermissionMetadataEntry) -> bool)
fn best_candidate( &self, key: &Identifier, context: &PermissionContext, ) -> Option<PermissionMetadataCandidate>
fn resolution( &self, candidate: PermissionMetadataCandidate, ) -> PermissionMetadataResolution